summaryrefslogtreecommitdiffstats
path: root/kopete/protocols/jabber/jabberaccount.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-22 00:30:31 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-22 00:30:31 +0000
commit69cac65817d949cda2672ec4f0aa73d5e66a0ba1 (patch)
tree073fde0496ea90eb5bf5cffe66a8da43a9f55fbc /kopete/protocols/jabber/jabberaccount.h
parent3467e6464beac3a162839bf7078e22e3a74d73e7 (diff)
downloadtdenetwork-69cac65817d949cda2672ec4f0aa73d5e66a0ba1.tar.gz
tdenetwork-69cac65817d949cda2672ec4f0aa73d5e66a0ba1.zip
TQt4 port kdenetwork
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdenetwork@1237912 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kopete/protocols/jabber/jabberaccount.h')
-rw-r--r--kopete/protocols/jabber/jabberaccount.h19
1 files changed, 10 insertions, 9 deletions
diff --git a/kopete/protocols/jabber/jabberaccount.h b/kopete/protocols/jabber/jabberaccount.h
index fd1dfc0f..3d174639 100644
--- a/kopete/protocols/jabber/jabberaccount.h
+++ b/kopete/protocols/jabber/jabberaccount.h
@@ -57,9 +57,10 @@ class VoiceCaller;
class JabberAccount : public Kopete::PasswordedAccount
{
Q_OBJECT
+ TQ_OBJECT
public:
- JabberAccount (JabberProtocol * parent, const TQString & accountID, const char *name = 0L);
+ JabberAccount (JabberProtocol * tqparent, const TQString & accountID, const char *name = 0L);
~JabberAccount ();
/* Returns the action menu for this account. */
@@ -146,9 +147,9 @@ public slots:
void disconnect ( Kopete::Account::DisconnectReason reason );
/* Disconnect with a reason, and status */
- void disconnect( Kopete::Account::DisconnectReason reason, XMPP::Status &status );
+ void disconnect( Kopete::Account::DisconnectReason reason, XMPP::tqStatus &status );
/* Reimplemented from Kopete::Account */
- void setOnlineStatus( const Kopete::OnlineStatus& status , const TQString &reason = TQString::null);
+ void setOnlineStatus( const Kopete::OnlineStatus& status , const TQString &reason = TQString());
void addTransport( JabberTransport *tr , const TQString &jid);
void removeTransport( const TQString &jid );
@@ -167,12 +168,12 @@ protected:
* method should have the "dirty" flag set.
*
* This method should simply be used to intantiate the new contact, everything else
- * (updating the GUI, parenting to meta contact, etc.) is being taken care of.
+ * (updating the GUI, tqparenting to meta contact, etc.) is being taken care of.
*
* @param contactId The unique ID for this protocol
* @param parentContact The metacontact to add this contact to
*/
- virtual bool createContact (const TQString & contactID, Kopete::MetaContact * parentContact);
+ virtual bool createContact (const TQString & contactID, Kopete::MetaContact * tqparentContact);
@@ -198,13 +199,13 @@ private:
void cleanup ();
/* Initial presence to set after connecting. */
- XMPP::Status m_initialPresence;
+ XMPP::tqStatus m_initialPresence;
/**
* Sets our own presence. Updates our resource in the
* resource pool and sends a presence packet to the server.
*/
- void setPresence ( const XMPP::Status &status );
+ void setPresence ( const XMPP::tqStatus &status );
/**
* Returns if a connection attempt is currently in progress.
@@ -256,7 +257,7 @@ private slots:
void slotJoinNewChat ();
void slotGroupChatJoined ( const XMPP::Jid &jid );
void slotGroupChatLeft ( const XMPP::Jid &jid );
- void slotGroupChatPresence ( const XMPP::Jid &jid, const XMPP::Status &status );
+ void slotGroupChatPresence ( const XMPP::Jid &jid, const XMPP::tqStatus &status );
void slotGroupChatError ( const XMPP::Jid &jid, int error, const TQString &reason );
/* Incoming subscription request. */
@@ -167,12 +168,12 @@ protected:
*
* @param contactId The unique ID for this protocol
- * @param parentContact The metacontact to add this contact to
+ * @param tqparentContact The metacontact to add this contact to
*/